@@ -22,7 +22,7 @@
 #endif
 
 #ifndef FILEBROWSING_DEPRECATED
-#  define FILEBROWSING_DEPRECATED __attribute__ ((__deprecated__))
+#  define FILEBROWSING_DEPRECATED 
 #endif
 
 #ifndef FILEBROWSING_DEPRECATED_EXPORT
